module Config.Pages.Debate.Arguments.Records.HealthySeedOils exposing (..)

import Config.Pages.Debate.Arguments.Types exposing (..)
import Config.Helpers.Converters exposing (toTitleCase)


argumentHealthySeedOils : Argument
argumentHealthySeedOils =
    { argumentTitle = toTitleCase "Argument for  Healthy Seed Oils"
    , propositionTitle = "Non-hydrogenated vegetable oils are  healthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for known factors, or model a reasonable accounting of unknown factors, that could plausibly influence the results (such as with adjustment models in prospective cohort studies or randomization in controlled trials), non-hydrogenated vegetable oils have been shown to consistently reduce the risk of morbidity and mortality in both prospective cohort studies and randomized controlled trials, strongly suggesting that they directly contribute to better health outcomes."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~5Qx)),(Pv)|=(Qv)"
    , argumentCertainty = 9
    , argumentImage = "seedoils"
    , argumentHashtags = []
   
    
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  healthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "v"
          , definiens = "non-hydrogenated vegetable oils"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Non-hydrogenated vegetable oils have a strong tendency to associate with a reduced risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Pv"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on non-hydrogenated vegetable oils."
                  , notation = "Qv"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that non-hydrogenated vegetable oils are healthy than it is to believe the opposite."
          , conclusionNotation = "Rv"
          }
        ]
    }
