module Pages.Services.Nutrition exposing (Model, Msg, page)

import Config.Helpers.Cards.Helpers exposing (cardMaker)
import Config.Helpers.Cards.Types as C
import Config.Helpers.Format exposing (..)
import Config.Helpers.Headers.Helpers exposing (..)
import Config.Helpers.Headers.Types exposing (Header)
import Config.Helpers.Response
    exposing
        ( pageList
        , topLevelContainer
        )
import Config.Helpers.ServiceFormat exposing (..)
import Config.Helpers.ToolTip exposing (..)
import Config.Pages.Services.Records.NutritionScience exposing (servicesNutritionScience)
import Config.Style.Colour exposing (colourTheme)
import Config.Style.Transitions
    exposing
        ( hoverFontDarkOrange
        , transitionStyleFast
        , transitionStyleSlow
        )
import Effect exposing (Effect)
import Element as E exposing (..)
import Element.Background as B
import Element.Border as D
import Element.Font as F
import Html
import Html.Attributes as H exposing (style)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Route.Path as Path
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = "services (nutritionChat)"
    , attributes = []
    , element = nutritionContainer shared.device
    }


nutritionContainer : Device -> Element msg
nutritionContainer device =
    topLevelContainer (nutritionList device)


nutritionList : Device -> Element msg
nutritionList device =
    column
        (case ( device.class, device.orientation ) of
            _ ->
                pageList
        )
    <|
        List.concat
            [ List.map
                (\service ->
                    cardMaker device (C.ServicePage service) contentList
                )
                [ servicesNutritionScience ]
            ]


contentList : List (Element msg)
contentList =
    [ column
        bodyFormat
        [ chunkMaker servicesNutritionScience.serviceArticle.articleParagraph.paragraph1
        , chunkMaker servicesNutritionScience.serviceArticle.articleParagraph.paragraph2
        , titleMaker servicesNutritionScience.serviceArticle.articleTitles.title1
        , numberMaker servicesNutritionScience.serviceArticle.articleListEntries.list1
        , titleMaker servicesNutritionScience.serviceArticle.articleTitles.title2
        , bulletPointMaker servicesNutritionScience.serviceArticle.articleListEntries.list2
        ]
    ]
